# timecube.py

> When you need to fill up space with something more interesting than Lorem Ipsum 



# Install

```bash
pip install timecube
```

# Usage

```pycon
import timecube


print(timecube.generate(0, timecube.timecubeLength))

```

# Parameters
### start: number (optional) 
default - 0
### stop: number (optional) 
default - timecube.timecubeLength


# License

MIT © [FullstackSoftwareInnovations](https://github.com/FullstackSoftwareInnovations)